pub struct Program<C> { /* private fields */ }Expand description
Program is the primary client handle to be used to build and send requests.
Implementations
Sourceimpl<C: Deref<Target = impl Signer> + Clone> Program<C>
impl<C: Deref<Target = impl Signer> + Clone> Program<C>
pub fn new(program_id: Pubkey, cfg: Config<C>) -> Result<Self, ClientError>
Available on non-crate feature
async only.pub fn rpc(&self) -> RpcClient
Available on non-crate feature
async and non-crate feature mock only.Sourcepub fn request(&self) -> RequestBuilder<'_, C, Box<dyn Signer + '_>>
Available on non-crate feature async only.
pub fn request(&self) -> RequestBuilder<'_, C, Box<dyn Signer + '_>>
async only.Returns a request builder.
Sourcepub fn account<T: AccountDeserialize>(
&self,
address: Pubkey,
) -> Result<T, ClientError>
Available on non-crate feature async only.
pub fn account<T: AccountDeserialize>( &self, address: Pubkey, ) -> Result<T, ClientError>
async only.Returns the account at the given address.
Sourcepub fn accounts<T: AccountDeserialize + Discriminator>(
&self,
filters: Vec<RpcFilterType>,
) -> Result<Vec<(Pubkey, T)>, ClientError>
Available on non-crate feature async only.
pub fn accounts<T: AccountDeserialize + Discriminator>( &self, filters: Vec<RpcFilterType>, ) -> Result<Vec<(Pubkey, T)>, ClientError>
async only.Returns all program accounts of the given type matching the given filters
Sourcepub fn accounts_lazy<T: AccountDeserialize + Discriminator>(
&self,
filters: Vec<RpcFilterType>,
) -> Result<ProgramAccountsIterator<T>, ClientError>
Available on non-crate feature async only.
pub fn accounts_lazy<T: AccountDeserialize + Discriminator>( &self, filters: Vec<RpcFilterType>, ) -> Result<ProgramAccountsIterator<T>, ClientError>
async only.Returns all program accounts of the given type matching the given filters as an iterator Deserialization is executed lazily
pub fn on<T: Event + AnchorDeserialize>( &self, f: impl FnMut(&EventContext, T) + Send + 'static, ) -> Result<EventUnsubscriber<'_>, ClientError>
Available on non-crate feature
async only.Auto Trait Implementations
impl<C> !Freeze for Program<C>
impl<C> !RefUnwindSafe for Program<C>
impl<C> !UnwindSafe for Program<C>
impl<C> Send for Program<C>where
C: Send,
impl<C> Sync for Program<C>where
C: Sync,
impl<C> Unpin for Program<C>where
C: Unpin,
impl<C> UnsafeUnpin for Program<C>where
C: UnsafeUnpin,